@@ -7,6 +7,9 @@ Date: 2021-01-26
 
 
 from .model import Model
+from ...common import get_ith_column
+from ...graphing import scatter
+
 from numpy import square, subtract
 
 
@@ -28,3 +31,8 @@ class RegressionModel(Model):
         evaluate the preformance of the model using MSE
         """
         return square(subtract(self.y.values, self.predict(self.X))).mean()
+
+    def plot(self, location=None):
+        x, x_label = get_ith_column(self.X, 0)
+        y = get_ith_column(self.predict(self.X), 0)[0]
+        scatter(x, y, "Predicted Regression", x_label, "y", location)
